@@ -98,6 +98,7 @@ __all__ = (
 
 import datetime
 import os
+from pathlib import Path
 
 import lsst_sphinx_bootstrap_theme
 
@@ -122,6 +123,7 @@ extensions = [
     "documenteer.sphinxext",
     "documenteer.sphinxext.lssttasks",
     "documenteer.ext.autocppapi",
+    "documenteer.ext.autodocreset",
     "sphinx_click",
 ]
 
@@ -181,6 +183,14 @@ exclude_patterns = [
     # shouldn't be in the directory at all, but we certainly need to
     # ignore it while its here.
     "home",
+    # The configuration files
+    "conf.py",
+    "manifest.yaml",
+    "doxygen.conf",
+    "doxygen.conf.in",
+    # Doxygen build products from scons (in stack package builds)
+    "html",
+    "xml",
 ]
 
 # ============================================================================
@@ -188,12 +198,12 @@ exclude_patterns = [
 # ============================================================================
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3/", None),
-    "numpy": ("https://docs.scipy.org/doc/numpy/", None),
+    "numpy": ("https://numpy.org/doc/stable/", None),
     "scipy": ("https://docs.scipy.org/doc/scipy/reference/", None),
     "matplotlib": ("https://matplotlib.org/", None),
     "sklearn": ("https://scikit-learn.org/stable/", None),
     "pandas": ("https://pandas.pydata.org/pandas-docs/stable/", None),
-    "astropy": ("http://docs.astropy.org/en/v3.0.x/", None),
+    "astropy": ("https://docs.astropy.org/en/stable/", None),
     "astro_metadata_translator": (
         "https://astro-metadata-translator.lsst.io",
         None,
@@ -298,9 +308,6 @@ html_file_suffix = ".html"
 # Language to be used for generating the HTML full-text search index.
 html_search_language = "en"
 
-html_extra_path = [""]
-
-
 # ============================================================================
 # #AUTOMODAPI automodapi and autodoc configuration
 # ============================================================================
@@ -336,7 +343,11 @@ autodoc_default_flags = ["show-inheritance", "special-members"]
 # ============================================================================
 # #DOXYLINK Doxylink configuration
 # ============================================================================
-doxylink = {"lsstcc": ("_doxygen/doxygen.tag", "cpp-api")}
+tag_path = Path(".").joinpath("_doxygen", "doxygen.tag")
+if tag_path.exists():
+    doxylink = {"lsstcc": (str(tag_path), "cpp-api")}
+else:
+    doxylink = {}
 
 documenteer_autocppapi_doxylink_role = "lsstcc"
 
